unit IDEExplorerData;

// It seems that using a data module prevents multiple, orphaned
// menu items when reinstalling during development. I guess that is
// because the items are reparented, but still have the same
// owner, the data module, which frees them on destruction.

// So if we want to prevent ghost items, we must remove them
// in the destructor of the expert. In a data module, this is
// done indirectly by freeinfg the data module, which will
// free the items it owns.

// I guess this can be done manually as well. Simply keep pointers
// to the items and free them when the expert is destroyed. I might
// do that to get rid of the data module.

interface

uses
  SysUtils, Classes, Menus;

type
  TExplorerData = class(TDataModule)
    PresetPopupMenu: TPopupMenu;
    TopExplorerSeparator: TMenuItem;
    IDEExplorerItem: TMenuItem;
    BottomExplorerSeparator: TMenuItem;
    procedure IDEExplorerItemClick(Sender: TObject);
  public
    constructor Create(AOwner: TComponent); override;
  end;

var
  ExplorerData: TExplorerData;

implementation

{$R *.dfm}

uses
  IDEExplorerForm, ToolsAPI;

procedure AddMenuItems;
var
  MainMenu: TMainMenu;
  ToolsMenu: TMenuItem;
  Item: TMenuItem;
  I, InsertPosition: Integer;
begin
  inherited;
  MainMenu := (BorlandIDEServices as INTAServices).MainMenu;

  // Default position
  ToolsMenu := MainMenu.Items[8];

  // Find "Tools" menu in main menu bar
  for I := 0 to MainMenu.Items.Count - 1 do
    if CompareText(MainMenu.Items[I].Name, 'ToolsMenu') = 0 then
    begin
      ToolsMenu := MainMenu.Items[I];
      Break;
    end;

  // Find "Debugger Options..." in "Tools" menu
  InsertPosition := ToolsMenu.Count;
  for I := 0 to ToolsMenu.Count - 1 do
    if CompareText('ToolsDebuggerOptionsItem', ToolsMenu.Items[I].Name) = 0 then
    begin
      InsertPosition := I + 1;
      Break;
    end;

  // Insert expert menu items
  for I := PresetPopupMenu.Items.Count - 1 downto 0 do
  begin
    // remove item from preset popup menu
    Item := PresetPopupMenu.Items[I];
    PresetPopupMenu.Items.Delete(I);

    // and add to IDE menu
    ToolsMenu.Insert(InsertPosition, Item);
  end;
end;

constructor TExplorerData.Create(AOwner: TComponent);
begin
  inherited;
  AddMenuItems;
end;

procedure TExplorerData.IDEExplorerItemClick(Sender: TObject);
var
  ExplorerForm: TExplorerForm;
begin
  ExplorerForm := TExplorerForm.Create(nil);
  try
    ExplorerForm.ShowModal;
  finally
    ExplorerForm.Free;
  end;
end;

end.
