{                                                                           }
{ File:       IDEExplorerExpert.pas                                         }
{ Function:   Expert code for IDE Explorer                                  }
{ Language:   Delphi for Win32                                              }
{ Author:     Rudy Velthuis                                                 }
{ Copyright:  (c) 2005 Rudy Velthuis                                        }
{ Disclaimer: This code is freeware. All rights are reserved.               }
{             This code is provided as is, expressly without a warranty     }
{             of any kind. You use it at your own risk.                     }
{                                                                           }
{             If you use this code, please credit me.                       }
{                                                                           }

unit IDEExplorerExpert;

interface

uses
  ToolsAPI;

procedure Register;

implementation

uses
  SysUtils, Classes, Dialogs, Menus, IDEExplorerForm;

type
  TIDEWizard = class(TInterfacedObject, IOTAWizard, IOTANotifier)
  private
    ExplorerForm: TExplorerForm;
    ExplorerItem: TMenuItem;
    ExplorerSeparator: TMenuItem;
    procedure AddMenuItems;
    procedure RemoveMenuItems;
  public
    constructor Create;
    destructor Destroy; override;
    function GetIDString: string;
    procedure Execute;
    function GetName: string;
    function GetState: TWizardState;
    procedure AfterSave;
    procedure BeforeSave;
    procedure Destroyed;
    procedure Modified;

    procedure ExplorerItemClick(Sender: TObject);
  end;

procedure Register;
begin
  RegisterPackageWizard(TIDEWizard.Create);
end;

{ TIDEWizard }

procedure TIDEWizard.AfterSave;
begin
  // nothing
end;

procedure TIDEWizard.BeforeSave;
begin
  // nothing
end;

constructor TIDEWizard.Create;
begin
  inherited;
  ExplorerForm := nil;
  AddMenuItems;
end;

destructor TIDEWizard.Destroy;
begin
  RemoveMenuItems;
  ExplorerForm.Free;
  inherited;
end;

procedure TIDEWizard.Destroyed;
begin
  // nothing
end;

procedure TIDEWizard.Execute;
begin
  // nothing
end;

function TIDEWizard.GetIDString: string;
begin
  Result := 'Velthuis.IDEExplorer';
end;

function TIDEWizard.GetName: string;
begin
  Result := 'IDE Explorer';
end;

function TIDEWizard.GetState: TWizardState;
begin
  Result := [wsEnabled];
end;

procedure TIDEWizard.Modified;
begin
  // nothing;
end;

procedure TIDEWizard.AddMenuItems;
var
  MainMenu: TMainMenu;
  ToolsMenu: TMenuItem;
  I, InsertPosition: Integer;
begin
  inherited;
  MainMenu := (BorlandIDEServices as INTAServices).MainMenu;

  // Use default position to start with.
  ToolsMenu := MainMenu.Items[8];

  // Find "Tools" menu in main menu bar.
  for I := 0 to MainMenu.Items.Count - 1 do
    if CompareText(MainMenu.Items[I].Name, 'ToolsMenu') = 0 then
    begin
      ToolsMenu := MainMenu.Items[I];
      Break;
    end;

  // Find "Debugger Options..." in "Tools" menu.
  InsertPosition := ToolsMenu.Count;
  for I := 0 to ToolsMenu.Count - 1 do
    if CompareText('ToolsToolsItem', ToolsMenu.Items[I].Name) = 0 then
    begin
      InsertPosition := I;
      Break;
    end;

  // Insert expert menu items.
  // References are kept so they can be freed when expert is removed.
  ExplorerSeparator := Menus.NewItem('-', 0, False, False, nil, 0, 'IDEXSeparator');
  ToolsMenu.InsertComponent(ExplorerSeparator);
  ToolsMenu.Insert(InsertPosition, ExplorerSeparator);
  ExplorerItem := Menus.NewItem('IDE Explorer', 0, False, True,
    ExplorerItemClick, 0, 'IDEExplorerItem');
  ToolsMenu.InsertComponent(ExplorerItem);
  ToolsMenu.Insert(InsertPosition, ExplorerItem);
end;

// Removes menu items when expert is removed.
procedure TIDEWizard.RemoveMenuItems;
begin
  ExplorerItem.Free;
  ExplorerSeparator.Free;
end;

procedure TIDEWizard.ExplorerItemClick(Sender: TObject);
begin
  if not Assigned(ExplorerForm) then
    ExplorerForm := TExplorerForm.Create(nil);
  ExplorerForm.Name := 'VelthuisIDEExplorerForm';
  ExplorerForm.ShowModal;
end;

end.
